@@ -6,8 +6,12 @@
 
 #include "localizer.h"
 
+#include <kitinerary_version.h>
 #include <KItinerary/JsonLdDocument>
 #include <KItinerary/Place>
+#if KITINERARY_VERSION >= QT_VERSION_CHECK(5, 24, 41)
+#include <KItinerary/PriceUtil>
+#endif
 
 #include <KContacts/Address>
 
@@ -28,6 +32,7 @@
 using namespace KAndroidExtras;
 #endif
 
+#include <cmath>
 #include <cstring>
 
 using namespace KItinerary;
@@ -252,3 +257,22 @@ QString Localizer::formatTemperature(double temperature)
 {
     return i18nc("temperature", "%1°C", (int)qRound(temperature));
 }
+
+QString Localizer::formatCurrency(double value, const QString &isoCode)
+{
+#if KITINERARY_VERSION >= QT_VERSION_CHECK(5, 24, 41)
+    const auto decimalCount = PriceUtil::decimalCount(isoCode);
+#else
+    const auto decimalCount = 2;
+#endif
+
+    // special case for displaying conversion rates (which can be very small)
+    // and thus need a higher precision than regular values
+    double i = 0.0;
+    double f = std::modf(value * std::pow(10, decimalCount), &i);
+    if (i == 0.0 && f > 0.0) {
+        return QLocale().toCurrencyString(value, isoCode);
+    }
+
+    return QLocale().toCurrencyString(value, isoCode, decimalCount);
+}
