@@ -20,10 +20,10 @@
 #include "genericpkpass.h"
 #include "healthcertificatemanager.h"
 #include "journeysectionmodel.h"
+#include "kdeconnect.h"
 #include "livedatamanager.h"
 #include "localizer.h"
 #include "locationinformation.h"
-#include "locationinformationdelegatecontroller.h"
 #include "mapdownloadmanager.h"
 #include "matrixcontroller.h"
 #include "navigationcontroller.h"
@@ -47,6 +47,7 @@
 #include "tripgroupinfoprovider.h"
 #include "tripgroupmanager.h"
 #include "tripgroupproxymodel.h"
+#include "unitconversion.h"
 #include "util.h"
 #include "weatherforecastmodel.h"
 
@@ -63,6 +64,10 @@
 #include <KItinerary/CountryDb>
 #include <KItinerary/JsonLdDocument>
 #include <KItinerary/Ticket>
+#include <kitinerary_version.h>
+#if KITINERARY_VERSION >= QT_VERSION_CHECK(5, 24, 41)
+#include <KItinerary/PriceUtil>
+#endif
 
 #include <KPkPass/Field>
 #include <KPkPass/Barcode>
@@ -111,6 +116,20 @@ class MatrixBeaconStub : public QObject
 };
 #endif
 
+#if KITINERARY_VERSION <QT_VERSION_CHECK(5, 24, 41)
+class DummyPriceUtil
+{
+    Q_GADGET
+ public:
+    Q_INVOKABLE static bool hasPrice(const QVariant&) { return false; }
+    Q_INVOKABLE static bool canHavePrice(const QVariant&) { return false; }
+    Q_INVOKABLE static double price(const QVariant&) { return 0.0; }
+    Q_INVOKABLE static QString currency(const QVariant&) { return QString(); }
+    Q_INVOKABLE static void setPrice(QVariant&, double, const QString&) {}
+    Q_INVOKABLE static int decimalCount(QStringView) { return 2; }
+};
+#endif
+
 void registerKContactsTypes()
 {
     // ### this should move into a real QML plugin for KContacts
@@ -148,6 +167,13 @@ void registerKItineraryTypes()
     qRegisterMetaType<KItinerary::KnowledgeDb::DrivingSide>();
     qmlRegisterUncreatableType<KItinerary::Ticket>("org.kde.kitinerary", 1, 0, "Ticket", {});
     qmlRegisterUncreatableMetaObject(KItinerary::KnowledgeDb::staticMetaObject, "org.kde.kitinerary", 1, 0, "KnowledgeDb", {});
+    qmlRegisterSingletonType("org.kde.itinerary", 1, 0, "PriceUtil", [](QQmlEngine*, QJSEngine *engine) -> QJSValue {
+#if KITINERARY_VERSION >= QT_VERSION_CHECK(5, 24, 41)
+        return engine->toScriptValue(KItinerary::PriceUtil());
+#else
+        return engine->toScriptValue(DummyPriceUtil());
+#endif
+    });
 }
 
 void registerApplicationTypes()
@@ -174,7 +200,7 @@ void registerApplicationTypes()
     qmlRegisterType<CountrySubdivisionModel>("org.kde.itinerary", 1, 0, "CountrySubdivisionModel");
     qmlRegisterType<DocumentsModel>("org.kde.itinerary", 1, 0, "DocumentsModel");
     qmlRegisterType<JourneySectionModel>("org.kde.itinerary", 1, 0, "JourneySectionModel");
-    qmlRegisterType<LocationInformationDelegateController>("org.kde.itinerary", 1, 0, "LocationInformationDelegateController");
+    qmlRegisterType<KDEConnectDeviceModel>("org.kde.itinerary", 1, 0, "KDEConnectDeviceModel");
     qmlRegisterType<StatisticsModel>("org.kde.itinerary", 1, 0, "StatisticsModel");
     qmlRegisterType<StatisticsTimeRangeModel>("org.kde.itinerary", 1, 0, "StatisticsTimeRangeModel");
     qmlRegisterType<TicketTokenModel>("org.kde.itinerary", 1, 0, "TicketTokenModel");
@@ -255,6 +281,7 @@ void registerApplicationSingletons()
     REGISTER_SINGLETON_GADGET_FACTORY(NotificationConfigController)
     REGISTER_SINGLETON_GADGET_FACTORY(PermissionManager)
     REGISTER_SINGLETON_GADGET_FACTORY(PublicTransport)
+    REGISTER_SINGLETON_GADGET_FACTORY(UnitConversion)
     REGISTER_SINGLETON_GADGET_FACTORY(Util)
 }
 
@@ -322,7 +349,6 @@ int main(int argc, char **argv)
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.itinerary")));
 
     auto aboutData = KAboutData::applicationData();
-    aboutData.setBugAddress("submit@bugs.kde.org");
     aboutData.setProductName("KDE Itinerary/general"); // Bugzilla product/component name
     aboutData.setLicense(KAboutLicense::LGPL_V2, KAboutLicense::OrLaterVersions);
     aboutData.setHomepage(QStringLiteral("https://apps.kde.org/itinerary"));
@@ -339,7 +365,7 @@ int main(int argc, char **argv)
     QCommandLineOption selfTestOpt(QStringLiteral("self-test"), QStringLiteral("internal, for automated testing"));
     parser.addOption(selfTestOpt);
     aboutData.setupCommandLine(&parser);
-    parser.addPositionalArgument(QStringLiteral("file"), i18n("PkPass or JSON-LD file to import."));
+    parser.addPositionalArgument(QStringLiteral("file"), i18n("Files or URLs to import."));
     parser.process(app);
     aboutData.processCommandLine(&parser);
 #if HAVE_KCRASH
@@ -452,6 +478,8 @@ int main(int argc, char **argv)
     });
 #endif
 
+    OnlineTicketImporter::setNetworkAccessManagerFactory(namFactory);
+
     registerKContactsTypes();
     registerKCalendarCoreTypes();
     registerKPkPassTypes();
