@@ -21,25 +21,60 @@ static QString permissionName(Permission::Permission p)
 {
     using namespace KAndroidExtras;
     switch (p) {
+        case Permission::InvalidPermission:
+            Q_UNREACHABLE();
         case Permission::ReadCalendar:
             return ManifestPermission::READ_CALENDAR;
         case Permission::WriteCalendar:
             return ManifestPermission::WRITE_CALENDAR;
+        case Permission::PostNotification:  // only for SDK >= 33
+            return ManifestPermission::POST_NOTIFICATIONS;
     }
 }
 #endif
 
-void PermissionManager::requestPermission(Permission::Permission permission, QJSValue callback)
+bool PermissionManager::checkPermission(Permission::Permission permission)
 {
-    qDebug() << permission;
-
+    if (permission == Permission::InvalidPermission) {
+        qWarning() << "check for invalid permission - check your QML code!";
+        return false;
+    }
 #ifdef Q_OS_ANDROID
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    if (QtAndroid::checkPermission(permissionName(permission)) == QtAndroid::PermissionResult::Granted) {
+    if (permission == Permission::PostNotification && QtAndroid::androidSdkVersion() < 33) {
+        return true;
+    }
+
+    return QtAndroid::checkPermission(permissionName(permission)) == QtAndroid::PermissionResult::Granted;
+#else
+    if (permission == Permission::PostNotification && QtAndroidPrivate::androidSdkVersion() < 33) {
+        return true;
+    }
+
+    return QtAndroidPrivate::checkPermission(permissionName(permission)).result() == QtAndroidPrivate::PermissionResult::Authorized;
+#endif
+#else // non-Android
+    Q_UNUSED(permission);
+    return true;
+#endif
+}
+
+void PermissionManager::requestPermission(Permission::Permission permission, QJSValue callback)
+{
+    if (permission == Permission::InvalidPermission) {
+        qWarning() << "request for invalid permission - check your QML code!";
+        return;
+    }
+
+    qDebug() << permission;
+    // already got the permission
+    if (PermissionManager::checkPermission(permission)) {
         callback.call();
         return;
     }
 
+#ifdef Q_OS_ANDROID
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QtAndroid::requestPermissions({permissionName(permission)}, [permission, callback] (const QtAndroid::PermissionResultMap &result) {
         if (result[permissionName(permission)] == QtAndroid::PermissionResult::Granted) {
             auto cb = callback;
@@ -55,8 +90,5 @@ void PermissionManager::requestPermission(Permission::Permission permission, QJS
     }
     callback.call();
 #endif
-#else
-    // non-Android
-    callback.call();
 #endif
 }
