@@ -116,7 +116,6 @@ QVariant ReservationManager::reservation(const QString& id) const
 
     // re-run post-processing to benefit from newer augmentations
     ExtractorPostprocessor postproc;
-    postproc.setValidationEnabled(false);
     postproc.process(resData);
     if (postproc.result().size() != 1) {
         qCWarning(Log) << "Post-processing discarded the reservation:" << resPath;
@@ -145,7 +144,6 @@ QString ReservationManager::batchesBasePath()
 QVector<QString> ReservationManager::importReservations(const QVector<QVariant> &resData)
 {
     ExtractorPostprocessor postproc;
-    postproc.setValidationEnabled(false);
     postproc.setContextDate(QDateTime(QDate::currentDate(), QTime(0, 0)));
     postproc.process(resData);
 
@@ -181,7 +179,7 @@ QVector<QString> ReservationManager::importReservations(const QVector<QVariant>
     return ids;
 }
 
-QString ReservationManager::addReservation(const QVariant &res)
+QString ReservationManager::addReservation(const QVariant &res, const QString &resIdHint)
 {
     // look for matching reservations, or matching batches
     // we need to do that within a +/-24h range, so we find unbound elements too
@@ -217,7 +215,7 @@ QString ReservationManager::addReservation(const QVariant &res)
             }
 
             // truly new, and added to an existing batch
-            const QString resId = QUuid::createUuid().toString(QUuid::WithoutBraces);
+            const QString resId = makeReservationId(resIdHint);
             storeReservation(resId, res);
             Q_EMIT reservationAdded(resId);
 
@@ -230,7 +228,7 @@ QString ReservationManager::addReservation(const QVariant &res)
     }
 
     // truly new, and starting a new batch
-    const QString resId = QUuid::createUuid().toString(QUuid::WithoutBraces);
+    const QString resId = makeReservationId(resIdHint);
     storeReservation(resId, res);
     Q_EMIT reservationAdded(resId);
 
@@ -550,3 +548,11 @@ QString ReservationManager::nextBatch(const QString& batchId) const
     }
     return *(it + 1);
 }
+
+QString ReservationManager::makeReservationId(const QString &resIdHint) const
+{
+    if (!resIdHint.isEmpty() && reservation(resIdHint).isNull()) {
+        return resIdHint;
+    }
+    return QUuid::createUuid().toString(QUuid::WithoutBraces);
+}
