@@ -82,6 +82,7 @@ void TimelineDelegateController::setReservationManager(QObject *resMgr)
     Q_EMIT contentChanged();
     Q_EMIT departureChanged();
     Q_EMIT arrivalChanged();
+    Q_EMIT journeyChanged();
     Q_EMIT previousLocationChanged();
     Q_EMIT layoutChanged();
 
@@ -109,6 +110,7 @@ void TimelineDelegateController::setLiveDataManager(QObject* liveDataMgr)
     Q_EMIT setupChanged();
     Q_EMIT departureChanged();
     Q_EMIT arrivalChanged();
+    Q_EMIT journeyChanged();
     Q_EMIT layoutChanged();
 
     connect(m_liveDataMgr, &LiveDataManager::arrivalUpdated, this, &TimelineDelegateController::checkForUpdate);
@@ -116,11 +118,20 @@ void TimelineDelegateController::setLiveDataManager(QObject* liveDataMgr)
     connect(m_liveDataMgr, &LiveDataManager::arrivalUpdated, this, [this](const auto &batchId) {
         if (batchId == m_batchId) {
             Q_EMIT arrivalChanged();
+            Q_EMIT journeyChanged();
         }
     });
     connect(m_liveDataMgr, &LiveDataManager::departureUpdated, this, [this](const auto &batchId) {
         if (batchId == m_batchId) {
             Q_EMIT departureChanged();
+            Q_EMIT journeyChanged();
+        }
+    });
+    connect(m_liveDataMgr, &LiveDataManager::journeyUpdated, this, [this](const auto &batchId) {
+        if (batchId == m_batchId) {
+            Q_EMIT departureChanged();
+            Q_EMIT arrivalChanged();
+            Q_EMIT journeyChanged();
         }
     });
 
@@ -173,6 +184,7 @@ void TimelineDelegateController::setBatchId(const QString &batchId)
     Q_EMIT contentChanged();
     Q_EMIT departureChanged();
     Q_EMIT arrivalChanged();
+    Q_EMIT journeyChanged();
     Q_EMIT previousLocationChanged();
     checkForUpdate(batchId);
 }
@@ -344,6 +356,7 @@ void TimelineDelegateController::batchChanged(const QString& batchId)
     Q_EMIT contentChanged();
     Q_EMIT arrivalChanged();
     Q_EMIT departureChanged();
+    Q_EMIT journeyChanged();
     Q_EMIT previousLocationChanged();
 }
 
@@ -924,20 +937,9 @@ void TimelineDelegateController::addToCalendar(KCalendarCore::Calendar *cal)
 
 static void applyVehicleLayout(KPublicTransport::Stopover &stop, const KPublicTransport::Stopover &layout)
 {
-    using namespace KPublicTransport;
-
-    if (!Stopover::isSame(stop, layout)) {
-        qDebug() << "stop mismatch";
-        return;
+    if (PublicTransport::isSameStopoverForLayout(stop, layout)) {
+        stop = KPublicTransport::Stopover::merge(stop, layout);
     }
-
-    const auto platform = stop.hasExpectedPlatform() ? stop.expectedPlatform() : stop.scheduledPlatform();
-    if (platform != layout.scheduledPlatform()) { // TODO this might need a more sophisticated check if there's platform sections involved
-        qDebug() << "platform mismatch";
-        return;
-    }
-
-    stop = Stopover::merge(stop, layout);
 }
 
 void TimelineDelegateController::setVehicleLayout(const KPublicTransport::Stopover& stopover, bool arrival)
@@ -947,12 +949,12 @@ void TimelineDelegateController::setVehicleLayout(const KPublicTransport::Stopov
         auto dep = jny.departure();
         applyVehicleLayout(dep, stopover);
         jny.setDeparture(dep);
-        m_liveDataMgr->setJourney(m_batchId, jny);
+        m_liveDataMgr->applyJourney(m_batchId, jny);
     } else {
         auto arr = jny.arrival();
         applyVehicleLayout(arr, stopover);
         jny.setArrival(arr);
-        m_liveDataMgr->setJourney(m_batchId, jny);
+        m_liveDataMgr->applyJourney(m_batchId, jny);
     }
 
     Q_EMIT layoutChanged();
